@@ -36,7 +36,7 @@ def check_input(naming):
     """Check and validate input params.
 
     Args:
-      naming (string): a string containing the naming type (label or index)
+      naming (string): a string containing the naming type (label or id).
 
     Returns:
       Nothing
@@ -55,7 +55,8 @@ def get_dimensions(js_dict, naming):
 
     Args:
       js_dict (dict): dictionary containing dataset data and metadata.
-      naming (string): a string containing the naming type (label or index).
+      naming (string, optional): dimension naming. Possible values: 'label' \
+                                 or 'id'.
 
     Returns:
       dimensions (list): list of pandas data frames with dimension \
@@ -166,14 +167,16 @@ def get_values(js_dict):
     return values
 
 
-def get_df_row(dimensions, i=0, record=None):
+def get_df_row(dimensions, naming='label', i=0, record=None):
     """Generate row dimension values for a pandas dataframe.
 
     Args:
       dimensions (list): list of pandas dataframes with dimension labels \
-                         generated by get_dim_label or get_dim_index methods
-      i (int, optional): dimension list iteration index. Default is 0, it's
-                         used in the recursive calls to the method.
+                         generated by get_dim_label or get_dim_index methods.
+      naming (string, optional): dimension naming. Possible values: 'label' \
+                                 or 'id'.
+      i (int): dimension list iteration index. Default is 0, it's used in the \
+                         recursive calls to the method.
       record (list): list of values representing a pandas dataframe row, \
                      except for the value column. Default is empty, it's used \
                      in the recursive calls to the method.
@@ -183,15 +186,16 @@ def get_df_row(dimensions, i=0, record=None):
 
     """
 
+    check_input(naming)
     if (i == 0 or record is None):
         record = []
-    for dimension in dimensions[i]['label']:
+    for dimension in dimensions[i][naming]:
         record.append(dimension)
         if len(record) == len(dimensions):
             yield record
 
         if i + 1 < len(dimensions):
-            for row in get_df_row(dimensions, i + 1, record):
+            for row in get_df_row(dimensions, naming, i + 1, record):
                 yield row
         if len(record) == i + 1:
             record.pop()
@@ -219,7 +223,8 @@ def from_json_stat(datasets, naming='label'):
 
     Args:
       data(string): data in JSON-stat format to decode.
-      naming(string): dimension naming. Possible values: 'label' or 'index'
+      naming(string, optional): dimension naming. Possible values: 'label'
+                                or 'id.'
 
     Returns:
       output(list): list of pandas.DataFrame with imported data.
@@ -237,7 +242,7 @@ def from_json_stat(datasets, naming='label'):
         values = get_values(js_dict)
         output = pd.DataFrame(columns=dim_names + [unicode('value', 'utf-8')],
                               index=range(0, len(values)))
-        for i, category in enumerate(get_df_row(dimensions)):
+        for i, category in enumerate(get_df_row(dimensions, naming)):
             output.loc[i] = category + [values.pop(0)]
         output = output.convert_objects(convert_numeric=True)
         results.append(output)
